#====================================
#          network_thread
#   Copyright 2011 - Nathan Osman
#
#  Manages network reuqests to and
# from the SE API and processes them
#       in a separate thread.
#
#   StackApplet is released under
#         the MIT license
#====================================

import Queue
import threading
import time

import urllib2
import zlib

# We need gobject for cross-thread signalling
import gobject
gobject.threads_init()

# Now lets see if we can import the JSON
# module. We try either of these two classes
try:
	import json
except ImportError:
	import simplejson as json

# Constants
API_VERSION = "1.1"
API_KEY     = "_qlxmEAOH06hLA1_FsZIGQ"

class network_thread(threading.Thread):
	
	def __init__(self):
		
		# Initialize the thread object
		threading.Thread.__init__(self)
		
		# The list of items that we will
		# be requesting.
		self.request_queue = Queue.Queue()
		
		# Set this thread as a daemon and start it
		self.setDaemon(True)
		self.start()
	
	def issue_request(self, site, method, callback, data, additional_params=''):
		
		url = "http://api." + site + ".com/" + API_VERSION + method +"?key=" + API_KEY
		
		if not additional_params == '':
			url += '&' + additional_params
		
		# Append the URL to the queue
		self.request_queue.put([url, callback, data])
	
	def run(self):
	
		# Now we run in circles waiting
		# for each request to come in.
		while True:
			
			# Get the next item
			item = self.request_queue.get(True)
			
			# Issue the request
			request = urllib2.Request(item[0])
			request.add_header('Accept-Encoding', 'gzip,deflate')
			
			opener = urllib2.build_opener()
			gzipped_stream = opener.open(request)
			raw_data = zlib.decompress(gzipped_stream.read(), 16+zlib.MAX_WBITS)
			
			json_data = json.loads(raw_data)
			
			time.sleep(1)
			gobject.idle_add(item[1], json_data, item[2])
